@@ -31,9 +31,9 @@
 #include <tqtextstream.h>
 
 // KDE includes
-#include <kapplication.h>
-#include <klocale.h>
-#include <kmessagebox.h>
+#include <tdeapplication.h>
+#include <tdelocale.h>
+#include <tdemessagebox.h>
 #include <kdebug.h>
 
 // system includes
@@ -64,34 +64,34 @@
 #include "smb4kauthinfo.h"
 #include "smb4ksambaoptionsinfo.h"
 #include "smb4kerror.h"
-#include "smb4kglobal.h"
+#include "smb4tdeglobal.h"
 #include "smb4ksambaoptionshandler.h"
 #include "smb4kpasswordhandler.h"
 #include "smb4kshare.h"
 #include "smb4ksettings.h"
 
-using namespace Smb4KGlobal;
+using namespace Smb4TDEGlobal;
 
 
 Smb4KMounter::Smb4KMounter( TQObject *parent, const char *name ) : TQObject( parent, name )
 {
   m_priv = new Smb4KMounterPrivate;
 
-  m_proc = new KProcess( this, "MounterProcess" );
+  m_proc = new TDEProcess( this, "MounterProcess" );
   m_proc->setUseShell( true );
 
   m_working = false;
 
   m_queue.setAutoDelete( true );
 
-  connect( m_proc,  TQT_SIGNAL( processExited( KProcess * ) ),
-           this,    TQT_SLOT( slotProcessExited( KProcess * ) ) );
+  connect( m_proc,  TQT_SIGNAL( processExited( TDEProcess * ) ),
+           this,    TQT_SLOT( slotProcessExited( TDEProcess * ) ) );
 
-  connect( m_proc,  TQT_SIGNAL( receivedStdout( KProcess *, char *, int ) ),
-           this,    TQT_SLOT( slotReceivedStdout( KProcess *, char *, int ) ) );
+  connect( m_proc,  TQT_SIGNAL( receivedStdout( TDEProcess *, char *, int ) ),
+           this,    TQT_SLOT( slotReceivedStdout( TDEProcess *, char *, int ) ) );
 
-  connect( m_proc,  TQT_SIGNAL( receivedStderr( KProcess *, char *, int ) ),
-           this,    TQT_SLOT( slotReceivedStderr( KProcess *, char *, int ) ) );
+  connect( m_proc,  TQT_SIGNAL( receivedStderr( TDEProcess *, char *, int ) ),
+           this,    TQT_SLOT( slotReceivedStderr( TDEProcess *, char *, int ) ) );
 
   connect( kapp,    TQT_SIGNAL( shutDown() ),
            this,    TQT_SLOT( slotShutdown() ) );
@@ -158,10 +158,10 @@ void Smb4KMounter::abort()
         }
       }
 
-      KProcess proc;
+      TDEProcess proc;
       proc.setUseShell( true );
       proc << TQString( "%1 smb4k_kill %2" ).arg( suid_program ).arg( m_proc->pid() );
-      proc.start( KProcess::DontCare, KProcess::NoCommunication );
+      proc.start( TDEProcess::DontCare, TDEProcess::NoCommunication );
     }
     else
     {
@@ -985,7 +985,7 @@ void Smb4KMounter::startProcess( int state )
     TQApplication::setOverrideCursor( waitCursor );
   }
 
-  m_proc->start( KProcess::NotifyOnExit, KProcess::AllOutput );
+  m_proc->start( TDEProcess::NotifyOnExit, TDEProcess::AllOutput );
 }
 
 
@@ -1538,19 +1538,19 @@ void Smb4KMounter::timerEvent( TQTimerEvent * )
 /////////////////////////////////////////////////////////////////////////////
 
 
-void Smb4KMounter::slotProcessExited( KProcess * )
+void Smb4KMounter::slotProcessExited( TDEProcess * )
 {
   endProcess();
 }
 
 
-void Smb4KMounter::slotReceivedStdout( KProcess *, char *buf, int len )
+void Smb4KMounter::slotReceivedStdout( TDEProcess *, char *buf, int len )
 {
   m_buffer.append( TQString::fromLocal8Bit( buf, len ) );
 }
 
 
-void Smb4KMounter::slotReceivedStderr( KProcess *, char *buf, int len )
+void Smb4KMounter::slotReceivedStderr( TDEProcess *, char *buf, int len )
 {
   m_buffer.append( TQString::fromLocal8Bit( buf, len ) );
 }
@@ -1652,7 +1652,7 @@ void Smb4KMounter::slotShutdown()
       }
     }
 
-    KProcess proc;
+    TDEProcess proc;
     proc.setUseShell( true );
     proc.detach();
 
@@ -1667,7 +1667,7 @@ void Smb4KMounter::slotShutdown()
 #else
           command.append( TQString( "%1 smb4k_umount " ).arg( suid_program ) );
 #endif
-          command.append( KProcess::quote( (*it)->path() ) );
+          command.append( TDEProcess::quote( (*it)->path() ) );
           command.append( " ; " );
         }
         else
@@ -1677,7 +1677,7 @@ void Smb4KMounter::slotShutdown()
 #else
           command.append( "smb4k_umount " );
 #endif
-          command.append( KProcess::quote( (*it)->path() ) );
+          command.append( TDEProcess::quote( (*it)->path() ) );
           command.append( " ; " );
         }
 
@@ -1685,19 +1685,19 @@ void Smb4KMounter::slotShutdown()
 
 #ifndef __FreeBSD__
         command.append( "rmdir --ignore-fail-on-non-empty " );
-        command.append( KProcess::quote( dir.canonicalPath() ) );
+        command.append( TDEProcess::quote( dir.canonicalPath() ) );
         command.append( " ; " );
         command.append( "rmdir --ignore-fail-on-non-empty " );
         dir.cdUp();
-        command.append( KProcess::quote( dir.canonicalPath() ) );
+        command.append( TDEProcess::quote( dir.canonicalPath() ) );
         command.append( " ; " );
 #else
         command.append( "rmdir " );
-        command.append( KProcess::quote( dir.canonicalPath() ) );
+        command.append( TDEProcess::quote( dir.canonicalPath() ) );
         command.append( " ; " );
         command.append( "rmdir " );
         dir.cdUp();
-        command.append( KProcess::quote( dir.canonicalPath() ) );
+        command.append( TDEProcess::quote( dir.canonicalPath() ) );
         command.append( " ; " );
 #endif
       }
@@ -1710,7 +1710,7 @@ void Smb4KMounter::slotShutdown()
     command.truncate( command.length() - 2 );
 
     proc << command;
-    proc.start( KProcess::DontCare, KProcess::NoCommunication );
+    proc.start( TDEProcess::DontCare, TDEProcess::NoCommunication );
   }
 }
 
