@@ -30,21 +30,21 @@
 #include <tqframe.h>
 
 // KDE includes
-#include <klocale.h>
-#include <kapplication.h>
+#include <tdelocale.h>
+#include <tdeapplication.h>
 #include <klineedit.h>
 #include <kdebug.h>
 
 // application specific includes
 #include "smb4kcustomoptionsdialog.h"
-#include "../core/smb4kglobal.h"
+#include "../core/smb4tdeglobal.h"
 #include "../core/smb4kcore.h"
 #include "../core/smb4ksambaoptionsinfo.h"
 #include "../core/smb4ksambaoptionshandler.h"
 #include "../core/smb4knetworkitems.h"
 #include "../core/smb4ksettings.h"
 
-using namespace Smb4KGlobal;
+using namespace Smb4TDEGlobal;
 
 
 // FIXME: Maybe introduce a private class here?
